@@ -58,6 +58,8 @@ int synth_1to1_stereo_avx (real*, real*, mpg123_handle*);
 int synth_1to1_arm        (real*, int, mpg123_handle*, int);
 int synth_1to1_neon       (real*, int, mpg123_handle*, int);
 int synth_1to1_stereo_neon(real*, real*, mpg123_handle*);
+int synth_1to1_neon64     (real*, int, mpg123_handle*, int);
+int synth_1to1_stereo_neon64(real*, real*, mpg123_handle*);
 /* This is different, special usage in layer3.c only.
    Hence, the name... and now forget about it.
    Never use it outside that special portion of code inside layer3.c! */
@@ -134,6 +136,8 @@ int synth_1to1_real_altivec    (real*, int, mpg123_handle*, int);
 int synth_1to1_real_stereo_altivec(real*, real*, mpg123_handle*);
 int synth_1to1_real_neon       (real*, int, mpg123_handle*, int);
 int synth_1to1_real_stereo_neon(real*, real*, mpg123_handle*);
+int synth_1to1_real_neon64     (real*, int, mpg123_handle*, int);
+int synth_1to1_real_stereo_neon64(real*, real*, mpg123_handle*);
 int synth_1to1_real_mono       (real*, mpg123_handle*);
 int synth_1to1_real_m2s(real*, mpg123_handle*);
 #ifndef NO_DOWNSAMPLE
@@ -167,6 +171,8 @@ int synth_1to1_s32_altivec    (real*, int, mpg123_handle*, int);
 int synth_1to1_s32_stereo_altivec(real*, real*, mpg123_handle*);
 int synth_1to1_s32_neon       (real*, int, mpg123_handle*, int);
 int synth_1to1_s32_stereo_neon(real*, real*, mpg123_handle*);
+int synth_1to1_s32_neon64     (real*, int, mpg123_handle*, int);
+int synth_1to1_s32_stereo_neon64(real*, real*, mpg123_handle*);
 int synth_1to1_s32_mono       (real*, mpg123_handle*);
 int synth_1to1_s32_m2s(real*, mpg123_handle*);
 #ifndef NO_DOWNSAMPLE
@@ -204,6 +210,8 @@ void dct36_3dnowext(real *,real *,real *,real *,real *);
 void dct36_x86_64  (real *,real *,real *,real *,real *);
 void dct36_sse     (real *,real *,real *,real *,real *);
 void dct36_avx     (real *,real *,real *,real *,real *);
+void dct36_neon    (real *,real *,real *,real *,real *);
+void dct36_neon64  (real *,real *,real *,real *,real *);
 
 /* Tools for NtoM resampling synth, defined in ntom.c . */
 int synth_ntom_set_step(mpg123_handle *fr); /* prepare ntom decoding */
