@@ -902,6 +902,188 @@ int synth_1to1_stereo_neon(real *bandPtr_l,real *bandPtr_r, mpg123_handle *fr)
 #endif
 #endif
 
+#ifdef OPT_NEON64
+#ifdef ACCURATE_ROUNDING
+/* This is defined in assembler. */
+int synth_1to1_neon64_accurate_asm(real *window, real *b0, short *samples, int bo1);
+int synth_1to1_s_neon64_accurate_asm(real *window, real *b0l, real *b0r, short *samples, int bo1);
+void dct64_real_neon64(real *out0, real *out1, real *samples);
+/* Hull for C mpg123 API */
+int synth_1to1_neon64(real *bandPtr,int channel, mpg123_handle *fr, int final)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);
+
+	real *b0, **buf;
+	int bo1;
+	int clip;
+
+	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
+
+	if(!channel)
+	{
+		fr->bo--;
+		fr->bo &= 0xf;
+		buf = fr->real_buffs[0];
+	}
+	else
+	{
+		samples++;
+		buf = fr->real_buffs[1];
+	}
+
+	if(fr->bo & 0x1)
+	{
+		b0 = buf[0];
+		bo1 = fr->bo;
+		dct64_real_neon64(buf[1]+((fr->bo+1)&0xf),buf[0]+fr->bo,bandPtr);
+	}
+	else
+	{
+		b0 = buf[1];
+		bo1 = fr->bo+1;
+		dct64_real_neon64(buf[0]+fr->bo,buf[1]+fr->bo+1,bandPtr);
+	}
+
+	clip = synth_1to1_neon64_accurate_asm(fr->decwin, b0, samples, bo1);
+
+	if(final) fr->buffer.fill += 128;
+
+	return clip;
+}
+
+int synth_1to1_stereo_neon64(real *bandPtr_l, real *bandPtr_r, mpg123_handle *fr)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);
+
+	real *b0l, *b0r, **bufl, **bufr;
+	int bo1;
+	int clip;
+
+	if(fr->have_eq_settings)
+	{
+		do_equalizer(bandPtr_l,0,fr->equalizer);
+		do_equalizer(bandPtr_r,1,fr->equalizer);
+	}
+
+	fr->bo--;
+	fr->bo &= 0xf;
+	bufl = fr->real_buffs[0];
+	bufr = fr->real_buffs[1];
+
+	if(fr->bo & 0x1)
+	{
+		b0l = bufl[0];
+		b0r = bufr[0];
+		bo1 = fr->bo;
+		dct64_real_neon64(bufl[1]+((fr->bo+1)&0xf),bufl[0]+fr->bo,bandPtr_l);
+		dct64_real_neon64(bufr[1]+((fr->bo+1)&0xf),bufr[0]+fr->bo,bandPtr_r);
+	}
+	else
+	{
+		b0l = bufl[1];
+		b0r = bufr[1];
+		bo1 = fr->bo+1;
+		dct64_real_neon64(bufl[0]+fr->bo,bufl[1]+fr->bo+1,bandPtr_l);
+		dct64_real_neon64(bufr[0]+fr->bo,bufr[1]+fr->bo+1,bandPtr_r);
+	}
+
+	clip = synth_1to1_s_neon64_accurate_asm(fr->decwin, b0l, b0r, samples, bo1);
+
+	fr->buffer.fill += 128;
+
+	return clip;
+}
+#else
+/* This is defined in assembler. */
+int synth_1to1_neon64_asm(short *window, short *b0, short *samples, int bo1);
+int synth_1to1_s_neon64_asm(short *window, short *b0l, short *b0r, short *samples, int bo1);
+void dct64_neon64(short *out0, short *out1, real *samples);
+/* Hull for C mpg123 API */
+int synth_1to1_neon64(real *bandPtr,int channel, mpg123_handle *fr, int final)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);	
+	short *b0, **buf;
+	int clip; 
+	int bo1;
+
+	if(fr->have_eq_settings) do_equalizer(bandPtr,channel,fr->equalizer);
+
+	if(!channel)
+	{
+		fr->bo--;
+		fr->bo &= 0xf;
+		buf = fr->short_buffs[0];
+	}
+	else
+	{
+		samples++;
+		buf = fr->short_buffs[1];
+	}
+
+	if(fr->bo & 0x1) 
+	{
+		b0 = buf[0];
+		bo1 = fr->bo;
+		dct64_neon64(buf[1]+((fr->bo+1)&0xf),buf[0]+fr->bo,bandPtr);
+	}
+	else
+	{
+		b0 = buf[1];
+		bo1 = fr->bo+1;
+		dct64_neon64(buf[0]+fr->bo,buf[1]+fr->bo+1,bandPtr);
+	}
+
+	clip = synth_1to1_neon64_asm((short *)fr->decwins, b0, samples, bo1);
+
+	if(final) fr->buffer.fill += 128;
+
+	return clip;
+}
+
+int synth_1to1_stereo_neon64(real *bandPtr_l,real *bandPtr_r, mpg123_handle *fr)
+{
+	short *samples = (short *) (fr->buffer.data+fr->buffer.fill);
+	short *b0l, *b0r, **bufl, **bufr;
+	int clip; 
+	int bo1;
+
+	if(fr->have_eq_settings)
+	{
+		do_equalizer(bandPtr_l,0,fr->equalizer);
+		do_equalizer(bandPtr_r,1,fr->equalizer);
+	}
+
+	fr->bo--;
+	fr->bo &= 0xf;
+	bufl = fr->short_buffs[0];
+	bufr = fr->short_buffs[1];
+
+	if(fr->bo & 0x1) 
+	{
+		b0l = bufl[0];
+		b0r = bufr[0];
+		bo1 = fr->bo;
+		dct64_neon64(bufl[1]+((fr->bo+1)&0xf),bufl[0]+fr->bo,bandPtr_l);
+		dct64_neon64(bufr[1]+((fr->bo+1)&0xf),bufr[0]+fr->bo,bandPtr_r);
+	}
+	else
+	{
+		b0l = bufl[1];
+		b0r = bufr[1];
+		bo1 = fr->bo+1;
+		dct64_neon64(bufl[0]+fr->bo,bufl[1]+fr->bo+1,bandPtr_l);
+		dct64_neon64(bufr[0]+fr->bo,bufr[1]+fr->bo+1,bandPtr_r);
+	}
+
+	clip = synth_1to1_s_neon64_asm((short *)fr->decwins, b0l, b0r, samples, bo1);
+
+	fr->buffer.fill += 128;
+
+	return clip;
+}
+#endif
+#endif
+
 #ifndef NO_DOWNSAMPLE
 
 /*
