@@ -1,7 +1,7 @@
 /*
 	xfermem: unidirectional fast pipe
 
-	copyright ?-2006 by the mpg123 project - free software under the terms of the LGPL 2.1
+	copyright ?-2008 by the mpg123 project - free software under the terms of the LGPL 2.1
 	see COPYING and AUTHORS files in distribution or http://mpg123.org
 	initially written by Oliver Fromme
 	old timestamp: Sun Apr  6 02:26:26 MET DST 1997
@@ -15,21 +15,18 @@
 #include "mpg123app.h"
 #include <string.h>
 #include <errno.h>
-#include <sys/time.h>
 #include <sys/uio.h>
 #include <sys/mman.h>
 #include <sys/socket.h>
 #include <fcntl.h>
 
-#ifdef AIX
-#include <sys/select.h>
-#endif
-
 #ifndef HAVE_MMAP
 #include <sys/ipc.h>
 #include <sys/shm.h>
 #endif
 
+#include "debug.h"
+
 #if defined (HAVE_MMAP) && defined(MAP_ANONYMOUS) && !defined(MAP_ANON)
 #define MAP_ANON MAP_ANONYMOUS
 #endif
@@ -219,6 +216,25 @@ int xfermem_block (int readwrite, txfermem *xf)
 	return ((result <= 0) ? -1 : result);
 }
 
+/* Parallel-safe code to signal a process and wait for it to respond. */
+int xfermem_sigblock(int readwrite, txfermem *xf, int pid, int signal)
+{
+	int myfd = xf->fd[readwrite];
+	int result;
+
+	xf->wakeme[readwrite] = TRUE;
+	kill(pid, signal);
+
+	/* not sure about that block... here */
+	if (xf->wakeme[1 - readwrite])
+		xfermem_putcmd (myfd, XF_CMD_WAKEUP);
+
+	result = xfermem_getcmd(myfd, TRUE);
+	xf->wakeme[readwrite] = FALSE;
+
+	return ((result <= 0) ? -1 : result);
+}
+
 int xfermem_write(txfermem *xf, byte *buffer, size_t bytes)
 {
 	if(buffer == NULL || bytes < 1) return FALSE;
@@ -295,6 +311,10 @@ int xfermem_block (int readwrite, txfermem *xf)
 {
   return 0;
 }
+int xfermem_sigblock (int readwrite, txfermem *xf, int pid, int signal)
+{
+  return 0;
+}
 #endif
 
 /* eof */
